@@ -112,14 +112,13 @@ def dumps_yaml(stream, *docs: Mapping) -> None:
 
 
 def load_yaml(p: Path) -> Dict:
-    yaml = _init_yaml()
     with p.open() as f:
-        return yaml.load(f)
+        return YAML(typ="safe").load(f)
 
 
 def loads_yaml(stream: Union[Text, IO]) -> Iterable[Dict]:
     """Dump yaml through a stream, using the default deserialisation settings."""
-    return _init_yaml().load_all(stream)
+    return YAML(typ="safe").load_all(stream)
 
 
 def from_path(path: Path) -> DatasetDoc:
@@ -277,7 +276,6 @@ _EO3_PROPERTY_ORDER = [
     "id",
     "label",
     "product",
-    "locations",
     "crs",
     "geometry",
     "grids",
@@ -285,6 +283,8 @@ _EO3_PROPERTY_ORDER = [
     "measurements",
     "accessories",
     "lineage",
+    "location",
+    "locations",
 ]
 
 
@@ -319,6 +319,8 @@ def prepare_formatting(d: Mapping) -> CommentedMap:
         "measurements",
         "accessories",
         "lineage",
+        "location",
+        "locations",
     )
 
     p: CommentedMap = doc["properties"]
